==> 507_3_1_1_newpda.zip: release/pages/payment_page.php <==
<?php
$asztalkod = $vars[1];
$jobID = $vars[2];

$kerekit=KEREKITES;
$kerekitSzamjegy=KEREKITESTIZEDES;
$defPenzem=ALAPERTELMEZETTPENZNEM;

define('STATION',  $_SESSION['station']); 

$action = '';

$fizetett=0;
$borravalo=0;

$reszszamla = (isset($_GET['reszszamla'])) ? (int)$_GET['reszszamla'] : 0;
$reszszamla = ($reszszamla==0) ? 0 : $reszszamla;

$fizetendo = (isset($_GET['fizetendo'])) ? $_GET['fizetendo'] : 0;
$fizetendo = ($fizetendo==0) ? 0 : $fizetendo;

$orRendID = (isset($_GET['orRendID'])) ? (int)$_GET['orRendID'] : 0;
$orRendID = ($orRendID==0) ? 0 : $orRendID;

$aktfizmod = (isset($_GET['aktFizKod'])) ? (int)$_GET['aktFizKod'] : 0;
$aktfizmod = ($aktfizmod==0) ? 0 : $aktfizmod;

$aktfizmodS = (isset($_GET['aktFizS'])) ? $_GET['aktFizS'] : "";
$aktfizmodS = ($aktfizmodS=="") ? "" : $aktfizmodS;

$checkConnected = myQuery("SELECT JobOrderItems.ENU_PRODUCT_1,
						  EnuProduct.Name,
						  JobOrderItems.jobOrdeItemsID, 
						  JobOrderItems.Quantity,
						  JobOrderItems.ConnectedToToolItemID,
						  joi2.ConnectedToToolItemID as cttiid,
						  EnuProduct.isWithProduct,
						  EnuProduct.withProductID,
						  EnuProduct.minOrderValue
				   FROM dbo.JobOrderItems 
				   LEFT JOIN dbo.JobOrderItems as joi2
					ON joi2.ConnectedToToolItemID=JobOrderItems.jobOrdeItemsID
				   LEFT JOIN dbo.EnuProduct
					ON EnuProduct.EnuProductID=JobOrderItems.ENU_PRODUCT_1
					LEFT JOIN dbo.EnuProduct as ep2
					ON ep2.EnuProductID=joi2.ENU_PRODUCT_1
				   WHERE JobOrderItems.deletedby is null AND JobOrderItems.JobOrderID=".$jobID." AND EnuProduct.withProductID !=0
				    AND (joi2.Quantity IS NULL OR ep2.minOrderValue*JobOrderItems.Quantity > (SELECT SUM(joss.Quantity) 
																								FROM JobOrderItems as joss 
																								WHERE joss.ConnectedToToolItemID=JobOrderItems.jobOrdeItemsID))
				   ORDER BY JobOrderItems.jobOrdeItemsID ASC;", null, false);
	
if ( is_array($checkConnected) && !empty($checkConnected) ) {
	redirect(URL . 'table/'.$asztalkod); 
	exit;
}

// ha van részszámla akkor go oda
if ($reszszamla==0) {
    $elsoResz = 0;
    $elsoReszCheck = myQuery("SELECT min(jobOrderID) as jobID FROM dbo.JobOrder WHERE originalJobOrderID=".$jobID.";");
    if (isset($elsoReszCheck) && is_array($elsoReszCheck) && $elsoReszCheck['jobID']>0)
    $elsoResz = $elsoReszCheck['jobID'];
    
    if ($elsoResz>0) {
      header('Location:'.URL.'invoice/'.$asztalkod.'/'.$jobID);
	  exit(); 
    }
}

if (isset($_GET['beallit']) && $_GET['beallit']=='1')
{
  $mithelyezat = (int)$_GET['syskod'];
  $mithelyezatS = $_GET['desc'];
  $ikonnev = $_GET['ikon'];
  
  $update_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[insertPdaFizmod] ".$mithelyezat.", ".$mithelyezatS.", '".$ikonnev."';";

	if (myQuery($update_query))
    {
       $action=lang('PAY_MODE_ADDED');   
    } 
    else
    {
       $action=lang('PAY_MODE_FAIL'); 
    }  
}

//Ha most kezdődik a fizetés, akkor a temp tábla tartalmát törölni kell...
if (isset($_GET['fizetesKezdodik']) && $_GET['fizetesKezdodik']=='1') {
  $kezdodik_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[deleteFizetesTempRendeles] ".$jobID.";";
  myQuery($kezdodik_query);

  $jobOrderAllapot=myQuery("UPDATE dbo.JobOrder SET SYS_TYPEDEF_1=40103 WHERE jobOrderID=$jobID");
  $jobOrderAllapot=myQuery("UPDATE dbo.asztalElrendezes SET allapot=40103 WHERE asztalKod=$asztalkod");

  $jobprint1 = myQuery("INSERT INTO dbo.nyomtatasok 
	  			   (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
				   VALUES
				   ($jobID, $asztalkod, {$_SESSION['userID']}, 1, '".date('Y-m-d H:i:s').".000');");
	
  $jobprint2 = myQuery("INSERT INTO dbo.nyomtatasok 
	  			   (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
				   VALUES
				   ($jobID, $asztalkod, {$_SESSION['userID']}, 2, '".date('Y-m-d H:i:s').".000');");
  
}

//Fizetési tétel hozzáadása
if (isset($_GET['fizetes_tetel']) && $_GET['fizetes_tetel']=='1') {
  $aktfizmod = (int)$_GET['aktFizMod'];

  $osszeg = $_GET['osszeg'];
  
  if ($aktfizmod>0)   {
      $tetelAdd_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[insertFizetesTemp] ".$jobID.", ".$aktfizmod.", ".$osszeg.", 1;";
      myQuery($tetelAdd_query);
      $aktfizmod=0;
  }
}

//Fizetési tétel törlése
if (isset($_GET['ftorol']) && $_GET['ftorol']=='1') {
  $akttetel = (int)$_GET['fizTempId'];
  $teteltorol_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[deleteFizetesTemp] ".$akttetel.";";
  myQuery($teteltorol_query);
}

//Fizetés lezárása
if (isset($_GET['fizetes_parancs']) && $_GET['fizetes_parancs']=='1') {
	$aktuser = $_SESSION['userID'];
	$aktrendeles = $jobID;
	$fizetendo = $_GET['fizetendo'];
	$fizetett = $_GET['fizetett'];
	$reszszamla = $_GET['reszszamla'];
	$eredetiRend = $_GET['orRendID'];

	if (!($fizetett<$fizetendo)) {
		if (1==1) {
			 $jobprint1 = myQuery("INSERT INTO dbo.nyomtatasok  (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
					   VALUES ($aktrendeles, $asztalkod, {$_SESSION['userID']}, 1, '".date('Y-m-d H:i:s').".000');");

			  $jobprint2 = myQuery("INSERT INTO dbo.nyomtatasok  (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
					   VALUES ($aktrendeles, $asztalkod, {$_SESSION['userID']}, 3, '".date('Y-m-d H:i:s').".000');");

			  $zarolSQL = "INSERT INTO dbo.sysjobOrderOpens  (jobOrderID,computerName,isPDAPay) 
					   VALUES ($aktrendeles, '".$_SESSION['computer']."', 1);";
			  $jobZarol = myQuery($zarolSQL);
			 
			if ($reszszamla==0) {
				header('Location:'.URL.'tables/');
				exit();   
			}
			else {
				header('Location:'.URL.'invoice/'.$asztalkod.'/'.$orRendID);
				exit(); 
			}
		}
		else{
			$action = lang('FAIL_CHECKOUT');  
		}
	}
	else
	{
	 $action = lang('NOT_FEED'); 
	}
}

?>
<div id="header-payment" class="header">
	<h2><?php echo lang('CHOOSE_PAYING_METHOD'); ?></h2>
</div>
<!-- tartalom start -->
<?php
$arf = 0;
$arfCheck = myQuery("SELECT sysStationID, CurrencyMUL FROM dbo.sysStation WHERE sysStationID=".STATION.";");
if (isset($arfCheck) && is_array($arfCheck) && $arfCheck['sysStationID']>0)
$arf = $arfCheck['CurrencyMUL'];

$eur = 0;
$eurCheck = myQuery("SELECT pdaFizModID, eur FROM dbo.PdaFizMod WHERE SysTypedefID=".$aktfizmod.";");
if (isset($eurCheck) && is_array($eurCheck) && isset($eurCheck['pdaFizModID']) && $eurCheck['pdaFizModID']>0)
$eur = $eurCheck['eur'];
$fennmarado=$fizetendo;
if ($eur==1) {
  $fennmarado=round($fennmarado/$arf,$kerekitSzamjegy);
  $penznem="EUR";  
} else {
  $penznem=$defPenzem;      
}

$tetelek ='';
$vannaktetelek = false;
				
//tételek lekérdezése DB-ből
$dbjobitems = array();
$jobFizSQL = "SELECT  dbo.fizetesTemp.*, dbo.SysTypedef.Description
				  FROM dbo.fizetesTemp LEFT OUTER JOIN  dbo.SysTypedef ON dbo.fizetesTemp.fizmodkod = dbo.SysTypedef.SysTypedefID 
				  WHERE rendelesKod=".$jobID.";";

$dbjobitems = myQuery($jobFizSQL, null, false);

//tételek kilistázása 
if (is_array($dbjobitems) && count($dbjobitems)>0)
{
	$vannaktetelek = true;
	$tetelek = '
	<table class="tbl_items" cellpadding="0" cellspacing="0" border="0">
				<a name=tetelek>
				<tr class="tbl_items_titles">
					
					<td><b>'.lang('PAYING_METHOD').'</b></td>
					<td><b>'.lang('AMOUNT').' (Ft)</b></td>
					<td><b>'.lang('AMOUNT').' (EUR)</b></td>
					<td><b>'.lang('DELETE').'</b></td>
				</tr>';

	$x=1;

	$fizetett=0;

	foreach($dbjobitems as $azonosito=>$p)
	{				
		if (floatval($p['fizetesTempID'])>0)
		{                   
			$name = iconv('ISO-8859-1', 'UTF-8', trim($p['Description']));
			$numberof = $p['fizetesTempID'];
			$osszFT = $p['osszegHUF'];
			$osszEUR = round($p['osszegEUR'],$kerekitSzamjegy);
			$fizetett+=$osszFT;
			$fennmarado = round($fizetendo-$fizetett,$kerekitSzamjegy);

			if ($eur==1) $fennmarado=round($fennmarado/$arf,$kerekitSzamjegy);

			if ($fennmarado<0) $fennmarado=0;
			
			$borravalo=0;
			if ($fizetett>$fizetendo)           {
				$borravalo=$fizetett-$fizetendo;
			} 

			if ($fizetett>$fizetendo*1.2) {
				$action = lang('MORE_THEN_20_PERCENT');
			}
											
			$rowtype = ($x%2==1) ? 'even' : 'odd';															
																																												  
			$tetelek .= '<form method="get" action="">
			<tr class="tbl_items_'.$rowtype.'">
							
							<td>'.$name.'</td>
							<td>'.$osszFT.'</td>
							<td>'.$osszEUR.'</td>

							<td>
							<input type="hidden" name="asztalkod" value="'.$asztalkod.'" />
							<input type="hidden" name="rendelesID" value="'.$jobID.'" />
							<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
							<input type="hidden" name="fizTempId" value="'.$numberof.'" />
							<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
							<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
							<input type="hidden" name="ftorol" value="1" />
							<input type="submit" class="button red-glossy" width="100" value="'.lang('DELETE').'" id="ftorol_parancs"></td>
							
						 </tr></form>';
			$x++;
		}
	}
	$tetelek .= '</table>';				
}

$tetelek2 ='<div class="payment-types after" >';
$vannaktetelek2 = false;
	
//tételek lekérdezése DB-ből
$dbjobitems2 = array();
$dbjobitems2 = myQuery("SELECT * FROM dbo.PdaFizMod;", null, false);

//tételek kilistázása 
if (is_array($dbjobitems2) && count($dbjobitems2)>0)
{
	$vannaktetelek2 = true;
	
	$x2=1;
	
	foreach($dbjobitems2 as $azonosito=>$p2)
	{					
		if (floatval($p2['pdaFizModID'])>0)
		{                   
			$name = iconv('UTF-8', 'ISO-8859-1', trim($p2['Descr']));
			
			$numberof = $p2['SysTypedefID'];
			$ikonn = URL . 'pdaicons/'.$p2['iconName'];
											
			$rowtype2 = ($x2%2==1) ? 'even' : 'odd';															
																																												  
			$tetelek2 .= '<div class="w-25">
							<form method="get" action="" class="fizu">
								<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
								<input type="hidden" name="aktFizKod" value="'.$numberof.'" />
								<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
								<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
								<input type="hidden" name="aktFizS" value="'.$name.'" />
								<input type="image" id="myimage" title="'.$name.'" src="'.$ikonn.'" />
							 </form>
							</div>';
			$x2++;
		}
	}
	$tetelek2 .= '</div>';	
}

echo '<div>
		<div id="fizu">
			'.$tetelek2.'  
		</div>
		<div id="bevitel">
		<form method="get" action="">
			<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
			<input type="hidden" name="aktFizMod" value="'.$aktfizmod.'" />
			<input type="hidden" name="aktFizS" value="'.$aktfizmodS.'" />
			<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
			<label>'.$aktfizmodS.'</label>';
			if($aktfizmodS != "") {
			echo '<input type="text" class="w-50" name="osszeg" id="osszeg_input" value="'.$fennmarado.'" />
			<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
			<input type="hidden" name="fizetes_tetel" value="1" />
			
			<input type="submit" class="button w-50 blue-glossy" width="100" value="'.lang('SAVE').'" id="osszeg_rogzites">';
			}
			echo '
		</form>
		</div>

		<div id="payment-tetelek">
			<label>Rögzitett Összegek</label>
			'.$tetelek.'
		</div>
		
		<br />

		<div id="sorok" class="after">
			<label class="w-50">'.lang('ALL_NEED_PAID').':</label>
			<label class="kiemel w-50">'.$fizetendo.' HUF</label>	  
				<br/>
			<label class="w-50">'.lang('UNTIL_PAID').':</label>
			<label class="kiemel w-50">'.$fizetett.' '.$penznem.'</label>	  
				<br/>
			<label class="w-50">'.lang('NEED_PAID').':</label>
			<label class="kiemel w-50">'.$fennmarado.' '.$penznem.'</label>	  
				<br/>
			<label class="w-50">'.lang('PLUS_PAID').':</label>
			<label class="kiemel w-50">'.$borravalo.' '.$penznem.'</label>	  
		</div>
		
		<br />
		
		<div id="done">
			<b style="font-size:1.1em"></b>
			<label>'.$action.'</label>
		<form method="get" action="">
			<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
			<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
			<input type="hidden" name="fizetett" value="'.$fizetett.'" />
			<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
			<input type="hidden" name="fizetes_parancs" value="1" />
			<input type="submit" class="button red-glossy" width="100" value="'.lang('CLOSE_PAYING').'" id="fizetes_lezaras">
		</form>
		<br>
		<a class="button blue-glossy" href="'.URL.'table/'.$asztalkod .'">'.lang('CANCEL').'</a>
	  </div>';
	 
?>

==> 507_3_2_1_newpda.zip: release/pages/payment_page.php <==
<?php
$asztalkod = (int)$vars[1];
$jobID = (int)$vars[2];

$kerekit=KEREKITES;
$kerekitSzamjegy=KEREKITESTIZEDES;
$defPenzem=ALAPERTELMEZETTPENZNEM;

define('STATION',  $_SESSION['station']); 

$action = '';

$fizetett=0;
$borravalo=0;

$reszszamla = (isset($_GET['reszszamla'])) ? (int)$_GET['reszszamla'] : 0;
$reszszamla = ($reszszamla==0) ? 0 : $reszszamla;

$fizetendo = (isset($_GET['fizetendo'])) ? (float)$_GET['fizetendo'] : 0;
$fizetendo = ($fizetendo==0) ? 0 : $fizetendo;

$orRendID = (isset($_GET['orRendID'])) ? (int)$_GET['orRendID'] : 0;
$orRendID = ($orRendID==0) ? 0 : $orRendID;

$aktfizmod = (isset($_GET['aktFizKod'])) ? (int)$_GET['aktFizKod'] : 0;
$aktfizmod = ($aktfizmod==0) ? 0 : $aktfizmod;

$aktfizmodS = (isset($_GET['aktFizS'])) ? (int)$_GET['aktFizS'] : "";
$aktfizmodS = ($aktfizmodS=="") ? "" : $aktfizmodS;

$checkConnected = myQuery("SELECT JobOrderItems.ENU_PRODUCT_1,
						  EnuProduct.Name,
						  JobOrderItems.jobOrdeItemsID, 
						  JobOrderItems.Quantity,
						  JobOrderItems.ConnectedToToolItemID,
						  joi2.ConnectedToToolItemID as cttiid,
						  EnuProduct.isWithProduct,
						  EnuProduct.withProductID,
						  EnuProduct.minOrderValue
				   FROM dbo.JobOrderItems 
				   LEFT JOIN dbo.JobOrderItems as joi2
					ON joi2.ConnectedToToolItemID=JobOrderItems.jobOrdeItemsID
				   LEFT JOIN dbo.EnuProduct
					ON EnuProduct.EnuProductID=JobOrderItems.ENU_PRODUCT_1
					LEFT JOIN dbo.EnuProduct as ep2
					ON ep2.EnuProductID=joi2.ENU_PRODUCT_1
				   WHERE JobOrderItems.deletedby is null AND JobOrderItems.JobOrderID=".$jobID." AND EnuProduct.withProductID !=0
				    AND (joi2.Quantity IS NULL OR ep2.minOrderValue*JobOrderItems.Quantity > (SELECT SUM(joss.Quantity) 
																								FROM JobOrderItems as joss 
																								WHERE joss.ConnectedToToolItemID=JobOrderItems.jobOrdeItemsID))
				   ORDER BY JobOrderItems.jobOrdeItemsID ASC;", null, false);
	
if ( is_array($checkConnected) && !empty($checkConnected) ) {
	redirect(URL . 'table/'.$asztalkod); 
	exit;
}

// ha van részszámla akkor go oda
if ($reszszamla==0) {
    $elsoResz = 0;
    $elsoReszCheck = myQuery("SELECT min(jobOrderID) as jobID FROM dbo.JobOrder WHERE originalJobOrderID=".$jobID.";");
    if (isset($elsoReszCheck) && is_array($elsoReszCheck) && $elsoReszCheck['jobID']>0)
    $elsoResz = $elsoReszCheck['jobID'];
    
    if ($elsoResz>0) {
      header('Location:'.URL.'invoice/'.$asztalkod.'/'.$jobID);
	  exit(); 
    }
}

if (isset($_GET['beallit']) && $_GET['beallit']=='1')
{
  $mithelyezat = (int)$_GET['syskod'];
  $mithelyezatS = myEscape($_GET['desc']);
  $ikonnev = myEscape($_GET['ikon']);
  
  $update_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[insertPdaFizmod] ".$mithelyezat.", ".$mithelyezatS.", ".$ikonnev.";";

	if (myQuery($update_query))
    {
       $action=lang('PAY_MODE_ADDED');   
    } 
    else
    {
       $action=lang('PAY_MODE_FAIL'); 
    }  
}

//Ha most kezdődik a fizetés, akkor a temp tábla tartalmát törölni kell...
if (isset($_GET['fizetesKezdodik']) && $_GET['fizetesKezdodik']=='1') {
  $kezdodik_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[deleteFizetesTempRendeles] ".$jobID.";";
  myQuery($kezdodik_query);

  $jobOrderAllapot=myQuery("UPDATE dbo.JobOrder SET SYS_TYPEDEF_1=40103 WHERE jobOrderID=$jobID");
  $jobOrderAllapot=myQuery("UPDATE dbo.asztalElrendezes SET allapot=40103 WHERE asztalKod=$asztalkod");

  $jobprint1 = myQuery("INSERT INTO dbo.nyomtatasok 
	  			   (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
				   VALUES
				   ($jobID, $asztalkod, {$_SESSION['userID']}, 1, '".date('Y-m-d H:i:s').".000');");
	
  $jobprint2 = myQuery("INSERT INTO dbo.nyomtatasok 
	  			   (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
				   VALUES
				   ($jobID, $asztalkod, {$_SESSION['userID']}, 2, '".date('Y-m-d H:i:s').".000');");
  
}

//Fizetési tétel hozzáadása
if (isset($_GET['fizetes_tetel']) && $_GET['fizetes_tetel']=='1') {
  $aktfizmod = (int)$_GET['aktFizMod'];

  $osszeg = (float)$_GET['osszeg'];
  
  if ($aktfizmod>0)   {
      $tetelAdd_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[insertFizetesTemp] ".$jobID.", ".$aktfizmod.", ".$osszeg.", 1;";
      myQuery($tetelAdd_query);
      $aktfizmod=0;
  }
}

//Fizetési tétel törlése
if (isset($_GET['ftorol']) && $_GET['ftorol']=='1') {
  $akttetel = (int)$_GET['fizTempId'];
  $teteltorol_query = "USE [".SZERVERADATBAZIS."] EXEC [dbo].[deleteFizetesTemp] ".$akttetel.";";
  myQuery($teteltorol_query);
}

//Fizetés lezárása
if (isset($_GET['fizetes_parancs']) && $_GET['fizetes_parancs']=='1') {
	$aktuser = $_SESSION['userID'];
	$aktrendeles = $jobID;
	$fizetendo = (float)$_GET['fizetendo'];
	$fizetett = (float)$_GET['fizetett'];
	$reszszamla = (int)$_GET['reszszamla'];
	$eredetiRend = (int)$_GET['orRendID'];

	if (!($fizetett<$fizetendo)) {
		if (1==1) {
			 $jobprint1 = myQuery("INSERT INTO dbo.nyomtatasok  (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
					   VALUES ($aktrendeles, $asztalkod, {$_SESSION['userID']}, 1, '".date('Y-m-d H:i:s').".000');");

			  $jobprint2 = myQuery("INSERT INTO dbo.nyomtatasok  (jobOrderID,asztalKod,felhasznaloKod,tipus,rogzites) 
					   VALUES ($aktrendeles, $asztalkod, {$_SESSION['userID']}, 3, '".date('Y-m-d H:i:s').".000');");

			  $zarolSQL = "INSERT INTO dbo.sysjobOrderOpens  (jobOrderID,computerName,isPDAPay) 
					   VALUES ($aktrendeles, '".$_SESSION['computer']."', 1);";
			  $jobZarol = myQuery($zarolSQL);
			 
			if ($reszszamla==0) {
				header('Location:'.URL.'tables/');
				exit();   
			}
			else {
				header('Location:'.URL.'invoice/'.$asztalkod.'/'.$orRendID);
				exit(); 
			}
		}
		else{
			$action = lang('FAIL_CHECKOUT');  
		}
	}
	else
	{
	 $action = lang('NOT_FEED'); 
	}
}

?>
<div id="header-payment" class="header">
	<h2><?php echo lang('CHOOSE_PAYING_METHOD'); ?></h2>
</div>
<!-- tartalom start -->
<?php
$arf = 0;
$arfCheck = myQuery("SELECT sysStationID, CurrencyMUL FROM dbo.sysStation WHERE sysStationID=".STATION.";");
if (isset($arfCheck) && is_array($arfCheck) && $arfCheck['sysStationID']>0)
$arf = $arfCheck['CurrencyMUL'];

$eur = 0;
$eurCheck = myQuery("SELECT pdaFizModID, eur FROM dbo.PdaFizMod WHERE SysTypedefID=".$aktfizmod.";");
if (isset($eurCheck) && is_array($eurCheck) && isset($eurCheck['pdaFizModID']) && $eurCheck['pdaFizModID']>0)
$eur = $eurCheck['eur'];
$fennmarado=$fizetendo;
if ($eur==1) {
  $fennmarado=round($fennmarado/$arf,$kerekitSzamjegy);
  $penznem="EUR";  
} else {
  $penznem=$defPenzem;      
}

$tetelek ='';
$vannaktetelek = false;
				
//tételek lekérdezése DB-ből
$dbjobitems = array();
$jobFizSQL = "SELECT  dbo.fizetesTemp.*, dbo.SysTypedef.Description
				  FROM dbo.fizetesTemp LEFT OUTER JOIN  dbo.SysTypedef ON dbo.fizetesTemp.fizmodkod = dbo.SysTypedef.SysTypedefID 
				  WHERE rendelesKod=".$jobID.";";

$dbjobitems = myQuery($jobFizSQL, null, false);

//tételek kilistázása 
if (is_array($dbjobitems) && count($dbjobitems)>0)
{
	$vannaktetelek = true;
	$tetelek = '
	<table class="tbl_items" cellpadding="0" cellspacing="0" border="0">
				<a name=tetelek>
				<tr class="tbl_items_titles">
					
					<td><b>'.lang('PAYING_METHOD').'</b></td>
					<td><b>'.lang('AMOUNT').' (Ft)</b></td>
					<td><b>'.lang('AMOUNT').' (EUR)</b></td>
					<td><b>'.lang('DELETE').'</b></td>
				</tr>';

	$x=1;

	$fizetett=0;

	foreach($dbjobitems as $azonosito=>$p)
	{				
		if (floatval($p['fizetesTempID'])>0)
		{                   
			$name = iconv('ISO-8859-1', 'UTF-8', trim($p['Description']));
			$numberof = $p['fizetesTempID'];
			$osszFT = $p['osszegHUF'];
			$osszEUR = round($p['osszegEUR'],$kerekitSzamjegy);
			$fizetett+=$osszFT;
			$fennmarado = round($fizetendo-$fizetett,$kerekitSzamjegy);

			if ($eur==1) $fennmarado=round($fennmarado/$arf,$kerekitSzamjegy);

			if ($fennmarado<0) $fennmarado=0;
			
			$borravalo=0;
			if ($fizetett>$fizetendo)           {
				$borravalo=$fizetett-$fizetendo;
			} 

			if ($fizetett>$fizetendo*1.2) {
				$action = lang('MORE_THEN_20_PERCENT');
			}
											
			$rowtype = ($x%2==1) ? 'even' : 'odd';															
																																												  
			$tetelek .= '<form method="get" action="">
			<tr class="tbl_items_'.$rowtype.'">
							
							<td>'.$name.'</td>
							<td>'.$osszFT.'</td>
							<td>'.$osszEUR.'</td>

							<td>
							<input type="hidden" name="asztalkod" value="'.$asztalkod.'" />
							<input type="hidden" name="rendelesID" value="'.$jobID.'" />
							<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
							<input type="hidden" name="fizTempId" value="'.$numberof.'" />
							<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
							<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
							<input type="hidden" name="ftorol" value="1" />
							<input type="submit" class="button red-glossy" width="100" value="'.lang('DELETE').'" id="ftorol_parancs"></td>
							
						 </tr></form>';
			$x++;
		}
	}
	$tetelek .= '</table>';				
}

$tetelek2 ='<div class="payment-types after" >';
$vannaktetelek2 = false;
	
//tételek lekérdezése DB-ből
$dbjobitems2 = array();
$dbjobitems2 = myQuery("SELECT * FROM dbo.PdaFizMod;", null, false);

//tételek kilistázása 
if (is_array($dbjobitems2) && count($dbjobitems2)>0)
{
	$vannaktetelek2 = true;
	
	$x2=1;
	
	foreach($dbjobitems2 as $azonosito=>$p2)
	{					
		if (floatval($p2['pdaFizModID'])>0)
		{                   
			$name = iconv('UTF-8', 'ISO-8859-1', trim($p2['Descr']));
			
			$numberof = $p2['SysTypedefID'];
			$ikonn = URL . 'pdaicons/'.$p2['iconName'];
											
			$rowtype2 = ($x2%2==1) ? 'even' : 'odd';															
																																												  
			$tetelek2 .= '<div class="w-25">
							<form method="get" action="" class="fizu">
								<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
								<input type="hidden" name="aktFizKod" value="'.$numberof.'" />
								<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
								<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
								<input type="hidden" name="aktFizS" value="'.$name.'" />
								<input type="image" id="myimage" title="'.$name.'" src="'.$ikonn.'" />
							 </form>
							</div>';
			$x2++;
		}
	}
	$tetelek2 .= '</div>';	
}

echo '<div>
		<div id="fizu">
			'.$tetelek2.'  
		</div>
		<div id="bevitel">
		<form method="get" action="">
			<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
			<input type="hidden" name="aktFizMod" value="'.$aktfizmod.'" />
			<input type="hidden" name="aktFizS" value="'.$aktfizmodS.'" />
			<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
			<label>'.$aktfizmodS.'</label>';
			if($aktfizmodS != "") {
			echo '<input type="text" class="w-50" name="osszeg" id="osszeg_input" value="'.$fennmarado.'" />
			<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
			<input type="hidden" name="fizetes_tetel" value="1" />
			
			<input type="submit" class="button w-50 blue-glossy" width="100" value="'.lang('SAVE').'" id="osszeg_rogzites">';
			}
			echo '
		</form>
		</div>

		<div id="payment-tetelek">
			<label>Rögzitett Összegek</label>
			'.$tetelek.'
		</div>
		
		<br />

		<div id="sorok" class="after">
			<label class="w-50">'.lang('ALL_NEED_PAID').':</label>
			<label class="kiemel w-50">'.$fizetendo.' HUF</label>	  
				<br/>
			<label class="w-50">'.lang('UNTIL_PAID').':</label>
			<label class="kiemel w-50">'.$fizetett.' '.$penznem.'</label>	  
				<br/>
			<label class="w-50">'.lang('NEED_PAID').':</label>
			<label class="kiemel w-50">'.$fennmarado.' '.$penznem.'</label>	  
				<br/>
			<label class="w-50">'.lang('PLUS_PAID').':</label>
			<label class="kiemel w-50">'.$borravalo.' '.$penznem.'</label>	  
		</div>
		
		<br />
		
		<div id="done">
			<b style="font-size:1.1em"></b>
			<label>'.$action.'</label>
		<form method="get" action="">
			<input type="hidden" name="orRendID" value="'.$orRendID.'"/>
			<input type="hidden" name="fizetendo" value="'.$fizetendo.'" />
			<input type="hidden" name="fizetett" value="'.$fizetett.'" />
			<input type="hidden" name="reszszamla" value="'.$reszszamla.'" />
			<input type="hidden" name="fizetes_parancs" value="1" />
			<input type="submit" class="button red-glossy" width="100" value="'.lang('CLOSE_PAYING').'" id="fizetes_lezaras">
		</form>
		<br>
		<a class="button blue-glossy" href="'.URL.'table/'.$asztalkod .'">'.lang('CANCEL').'</a>
	  </div>';
	 
?>
